@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.9.2"
+__version__ = "0.11.0"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -948,6 +948,12 @@ class MinicondaComponent(Component):
                 help="Install Miniconda at the given path",
             ),
             Option("--batch", is_flag=True, help="Run in batch (noninteractive) mode"),
+            Option(
+                "-c",
+                "--channel",
+                multiple=True,
+                help="Additional Conda channels to install packages from",
+            ),
             Option(
                 "--spec",
                 converter=str.split,
@@ -977,6 +983,7 @@ class MinicondaComponent(Component):
         spec: Optional[List[str]] = None,
         python_match: Optional[str] = None,
         extra_args: Optional[List[str]] = None,
+        channel: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
         log.info("Installing Miniconda")
@@ -995,6 +1002,7 @@ class MinicondaComponent(Component):
             log.info("Batch: True")
         else:
             log.info("Batch: %s", batch)
+        log.info("Channels: %s", channel)
         log.info("Spec: %s", spec)
         log.info("Python Match: %s", python_match)
         log.info("Extra args: %s", extra_args)
@@ -1063,6 +1071,9 @@ class MinicondaComponent(Component):
             install_args: List[str] = []
             if batch:
                 install_args.append("--yes")
+            if channel is not None:
+                for c in channel:
+                    install_args.extend(["--channel", c])
             install_args.extend(spec)
             runcmd(conda_instance.conda_exe, "install", *install_args)
         self.manager.conda_stack.append(conda_instance)
@@ -1795,6 +1806,7 @@ class SnapshotInstaller(AutobuildSnapshotInstaller):
 @GitAnnexComponent.register_installer
 @DataladComponent.register_installer
 @RCloneComponent.register_installer
+@GitAnnexRemoteRCloneComponent.register_installer
 class CondaInstaller(Installer):
     """Installs via conda"""
 
@@ -1808,6 +1820,10 @@ class CondaInstaller(Installer):
         "datalad": ("datalad", [DATALAD_CMD]),
         "git-annex": ("git-annex", [GIT_ANNEX_CMD]),
         "rclone": ("rclone", [RCLONE_CMD]),
+        "git-annex-remote-rclone": (
+            "git-annex-remote-rclone",
+            [GIT_ANNEX_REMOTE_RCLONE_CMD],
+        ),
     }
 
     def __init__(
@@ -1823,9 +1839,9 @@ class CondaInstaller(Installer):
         extra_args: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> Path:
-        if package == "git-annex" and not ON_LINUX:
+        if package in ("git-annex", "git-annex-remote-rclone") and not ON_LINUX:
             raise MethodNotSupportedError(
-                "Conda only supports installing git-annex on Linux"
+                f"Conda only supports installing {package} on Linux"
             )
         log.info("Installing %s via conda", package)
         if self.conda_instance is not None:
@@ -2016,45 +2032,90 @@ class DataladPackagesBuildInstaller(Installer):
 
     NAME = "datalad/packages"
 
-    OPTIONS: ClassVar[List[Option]] = []
+    OPTIONS = [
+        Option(
+            "--install-dir",
+            converter=Path,
+            metavar="DIR",
+            help="Directory in which to unpack the `*.deb`",
+        ),
+    ]
 
     PACKAGES = {
         "git-annex": ("git-annex", [GIT_ANNEX_CMD]),
     }
 
     def install_package(
-        self, package: str, version: Optional[str] = None, **kwargs: Any
+        self,
+        package: str,
+        version: Optional[str] = None,
+        install_dir: Optional[Path] = None,
+        **kwargs: Any,
     ) -> Path:
         log.info("Installing %s via datalad/packages", package)
         log.info("Version: %s", version)
+        if install_dir is not None:
+            if not ON_LINUX:
+                raise RuntimeError("--install-dir is only supported on Linux")
+            install_dir = untmppath(install_dir)
+            log.info("Install dir: %s", install_dir)
         if kwargs:
             log.warning("Ignoring extra installer arguments: %r", kwargs)
         assert package == "git-annex"
-        # Installing under a tempfile.TemporaryDirectory() leads to an error
-        # when Python tries to clean up the directory, so we'll just leave the
-        # .exe file alone.
-        tmpdir = mktempdir("dl-datalad-package-")
-        if ON_WINDOWS:
-            if version is None:
-                exefile = "git-annex-installer_latest-snapshot_x64.exe"
-            else:
-                exefile = f"git-annex-installer_{version}_x64.exe"
-            exepath = tmpdir / exefile
-            download_file(
-                f"https://datasets.datalad.org/datalad/packages/windows/{exefile}",
-                exepath,
+        if version is None:
+            log.info("Fetching latest version ...")
+            vfile = download_to_tempfile(
+                "http://datasets.datalad.org/datalad/packages/latest-version"
             )
-            self.manager.run_maybe_elevated(exepath, "/S")
-            binpath = Path("C:/Program Files", "Git", "usr", "bin")
-            self.manager.addpath(binpath)
-        else:
-            raise AssertionError("Method should not be called on unsupported platforms")
+            version = vfile.read_text().strip()
+            log.info("Found latest version: %s", version)
+        # Try to ignore cleanup errors on Windows:
+        with suppress(NotADirectoryError), tempfile.TemporaryDirectory() as tmpdir_:
+            tmpdir = Path(tmpdir_)
+            if ON_LINUX:
+                debfile = f"git-annex-standalone_{version}-1~ndall+1_amd64.deb"
+                debpath = tmpdir / debfile
+                download_file(
+                    f"https://datasets.datalad.org/datalad/packages/neurodebian/{debfile}",
+                    debpath,
+                )
+                if install_dir is None and deb_pkg_installed("git-annex"):
+                    self.manager.sudo(
+                        "dpkg", "--remove", "--ignore-depends=git-annex", "git-annex"
+                    )
+                binpath = install_deb(
+                    debpath,
+                    self.manager,
+                    Path("usr", "bin"),
+                    install_dir=install_dir,
+                )
+            elif ON_WINDOWS:
+                exefile = f"git-annex-installer_{version}_x64.exe"
+                exepath = tmpdir / exefile
+                download_file(
+                    f"https://datasets.datalad.org/datalad/packages/windows/{exefile}",
+                    exepath,
+                )
+                self.manager.run_maybe_elevated(exepath, "/S")
+                binpath = Path("C:/Program Files", "Git", "usr", "bin")
+                self.manager.addpath(binpath)
+            elif ON_MACOS:
+                dmgfile = f"git-annex_{version}_x64.dmg"
+                dmgpath = tmpdir / dmgfile
+                download_file(
+                    f"https://datasets.datalad.org/datalad/packages/osx/{dmgfile}",
+                    dmgpath,
+                )
+                binpath = install_git_annex_dmg(dmgpath, self.manager)
+            else:
+                raise AssertionError(
+                    "Method should not be called on unsupported platforms"
+                )
         log.debug("Installed program directory: %s", binpath)
         return binpath
 
     def assert_supported_system(self) -> None:
-        if not ON_WINDOWS:
-            raise MethodNotSupportedError(f"{SYSTEM} OS not supported")
+        pass
 
 
 @GitAnnexComponent.register_installer
@@ -2248,6 +2309,8 @@ class DownloadsRCloneInstaller(Installer):
                     contents / "rclone.1", man1_dir / "rclone.1"
                 )
         log.debug("Installed program directory: %s", bin_dir)
+        if str(bin_dir) not in os.environ.get("PATH", "").split(os.pathsep):
+            self.manager.addpath(bin_dir)
         return bin_dir
 
     def assert_supported_system(self) -> None:
@@ -2278,8 +2341,12 @@ class GitHubClient:
     def get(self, url: str) -> Iterator[Any]:
         log.debug("HTTP request: GET %s", url)
         req = Request(url, headers=self.headers)
-        with urlopen(req) as r:
-            yield r
+        try:
+            with urlopen(req) as r:
+                yield r
+        except URLError as e:
+            raise_for_ratelimit(e, self.headers.get("Authorization"))
+            raise
 
     def getjson(self, url: str) -> Any:
         with self.get(url) as r:
@@ -2436,6 +2503,31 @@ class MethodNotSupportedError(Exception):
     pass
 
 
+def raise_for_ratelimit(e: URLError, auth: Optional[str]) -> None:
+    if isinstance(e, HTTPError) and e.code == 403:
+        try:
+            resp = json.load(e)
+        except Exception:
+            return
+        if "API rate limit exceeded" in resp.get("message", ""):
+            if auth is not None:
+                url = "https://api.github.com/rate_limit"
+                log.debug("HTTP request: GET %s", url)
+                req = Request(url, headers={"Authorization": auth})
+                with urlopen(req) as r:
+                    resp = json.load(r)
+                log.info(
+                    "GitHub rate limit exceeded; details:\n\n%s\n",
+                    textwrap.indent(json.dumps(resp, indent=4), " " * 4),
+                )
+            else:
+                raise RuntimeError(
+                    "GitHub rate limit exceeded and GITHUB_TOKEN not set;"
+                    " suggest setting GITHUB_TOKEN in order to get increased"
+                    " rate limit"
+                )
+
+
 def download_file(
     url: str, path: Union[str, os.PathLike], headers: Optional[Dict[str, str]] = None
 ) -> None:
@@ -2456,6 +2548,7 @@ def download_file(
             return
         except URLError as e:
             if isinstance(e, HTTPError) and e.code not in (500, 502, 503, 504):
+                raise_for_ratelimit(e, headers.get("Authorization"))
                 raise
             try:
                 delay = next(delays)
