@@ -58,10 +58,6 @@ def test_install_miniconda(tmp_path: Path) -> None:
     )
 
 
-@pytest.mark.skipif(
-    sys.version_info[:2] < (3, 7),
-    reason="Trying to install Python 3.6 on Conda gives package conflicts",
-)
 @pytest.mark.skipif(
     sys.version_info[:2] == (3, 11),
     reason="Python 3.11 not yet available on Conda",
@@ -94,6 +90,37 @@ def test_install_miniconda_python_match(tmp_path: Path) -> None:
     ).stdout.strip() == repr(sys.version_info[:2])
 
 
+@pytest.mark.skipif(sys.version_info[:2] != (3, 11), reason="Only run on Python 3.11")
+@pytest.mark.miniconda
+def test_install_miniconda_python_match_conda_forge(tmp_path: Path) -> None:
+    miniconda_path = tmp_path / "conda"
+    r = main(
+        [
+            "datalad_installer.py",
+            "miniconda",
+            "--batch",
+            "--path",
+            str(miniconda_path),
+            "--python-match",
+            "minor",
+            "-c",
+            "conda-forge",
+        ]
+    )
+    assert r == 0
+    if ON_WINDOWS:
+        pypath = miniconda_path / "python.exe"
+    else:
+        pypath = miniconda_path / "bin" / "python"
+    assert pypath.exists()
+    assert subprocess.run(
+        [str(pypath), "-c", "import sys; print(sys.version_info[:2])"],
+        stdout=subprocess.PIPE,
+        universal_newlines=True,
+        check=True,
+    ).stdout.strip() == repr(sys.version_info[:2])
+
+
 @pytest.mark.miniconda
 def test_install_miniconda_autogen_path(monkeypatch: pytest.MonkeyPatch) -> None:
     # Override TMPDIR with a path that will be cleaned up afterwards (We can't
